@@ -138,7 +138,12 @@ class ShapeNode:
         if doc:
             self.print_shape_doc(output, self.shape)
 
-        if not self.shape.members:
+        if self.is_exception:
+            error_spec = self.shape.metadata.get("error", {})
+            output.write(f'    code: str = "{error_spec.get("code", self.shape.name)}"\n')
+            output.write(f'    sender_fault: bool = {error_spec.get("senderFault", False)}\n')
+            output.write(f'    status_code: int = {error_spec.get("httpStatusCode", 400)}\n')
+        elif not self.shape.members:
             output.write("    pass\n")
 
         for k, v in self.shape.members.items():
@@ -442,6 +447,9 @@ def generate_code(service_name: str, doc: bool = False) -> str:
 
 def create_code_directory(service_name: str, code: str, base_path: str):
     service_name = service_name.replace("-", "_")
+    # handle service names which are reserved keywords in python (f.e. lambda)
+    if is_keyword(service_name):
+        service_name += "_"
     path = Path(base_path, service_name)
 
     if not path.exists():
@@ -465,7 +473,7 @@ def upgrade(path: str, doc: bool = False):
     Execute the code generation for all existing APIs.
     """
     services = [
-        d.name.replace("_", "-")
+        d.name.rstrip("_").replace("_", "-")
         for d in Path(path).iterdir()
         if d.is_dir() and not d.name.startswith("__")
     ]
