@@ -1,7 +1,11 @@
 import json
+import logging
 import os
 import sys
-from typing import Dict, Optional
+from typing import Dict, List, Optional
+
+from localstack import config
+from localstack.utils.analytics.cli import publish_invocation
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -28,13 +32,12 @@ def create_with_plugins() -> LocalstackCli:
 
 
 def _setup_cli_debug():
-    from localstack import config
-    from localstack.utils.bootstrap import setup_logging
+    from localstack.logging.setup import setup_logging_for_cli
 
     config.DEBUG = True
     os.environ["DEBUG"] = "1"
 
-    setup_logging()
+    setup_logging_for_cli(logging.DEBUG if config.DEBUG else logging.INFO)
 
 
 @click.group(name="localstack", help="The LocalStack Command Line Interface (CLI)")
@@ -44,10 +47,15 @@ def _setup_cli_debug():
 def localstack(debug, profile):
     if profile:
         os.environ["CONFIG_PROFILE"] = profile
-
     if debug:
         _setup_cli_debug()
 
+    from localstack.utils.files import cache_dir
+
+    # overwrite the config variable here to defer import of cache_dir
+    if not config.LEGACY_DIRECTORIES and not os.environ.get("LOCALSTACK_VOLUME_DIR", "").strip():
+        config.VOLUME_DIR = cache_dir() / "volume"
+
 
 @localstack.group(name="config", help="Inspect your LocalStack configuration")
 def localstack_config():
@@ -69,6 +77,7 @@ def localstack_status(ctx):
     name="docker", help="Query information about the LocalStack Docker image and runtime"
 )
 @click.option("--format", type=click.Choice(["table", "plain", "dict", "json"]), default="table")
+@publish_invocation
 def cmd_status_docker(format):
     with console.status("Querying Docker status"):
         print_docker_status(format)
@@ -76,11 +85,10 @@ def cmd_status_docker(format):
 
 @localstack_status.command(name="services", help="Query information about running services")
 @click.option("--format", type=click.Choice(["table", "plain", "dict", "json"]), default="table")
+@publish_invocation
 def cmd_status_services(format):
     import requests
 
-    from localstack import config
-
     url = config.get_edge_url()
 
     try:
@@ -111,6 +119,7 @@ def cmd_status_services(format):
 @click.option(
     "-d", "--detached", is_flag=True, help="Start LocalStack in the background", default=False
 )
+@publish_invocation
 def cmd_start(docker: bool, host: bool, no_banner: bool, detached: bool):
     if docker and host:
         raise click.ClickException("Please specify either --docker or --host")
@@ -145,8 +154,8 @@ def cmd_start(docker: bool, host: bool, no_banner: bool, detached: bool):
 
 
 @localstack.command(name="stop", help="Stop the running LocalStack container")
+@publish_invocation
 def cmd_stop():
-    from localstack import config
     from localstack.utils.docker_utils import DOCKER_CLIENT
 
     from ..utils.container_utils.container_client import NoSuchContainer
@@ -169,8 +178,8 @@ def cmd_stop():
     help="Block the terminal and follow the log output",
     default=False,
 )
+@publish_invocation
 def cmd_logs(follow: bool):
-    from localstack import config
     from localstack.utils.docker_utils import DOCKER_CLIENT
 
     container_name = config.MAIN_CONTAINER_NAME
@@ -194,6 +203,7 @@ def cmd_logs(follow: bool):
     help="The amount of time in seconds to wait before raising a timeout error",
     default=None,
 )
+@publish_invocation
 def cmd_wait(timeout: Optional[float] = None):
     from localstack.utils.bootstrap import wait_container_is_ready
 
@@ -209,6 +219,7 @@ def cmd_wait(timeout: Optional[float] = None):
     default="docker-compose.yml",
     type=click.Path(exists=True, file_okay=True, readable=True),
 )
+@publish_invocation
 def cmd_config_validate(file):
     from rich.panel import Panel
 
@@ -229,13 +240,12 @@ def cmd_config_validate(file):
 
 @localstack_config.command(name="show", help="Print the current LocalStack config values")
 @click.option("--format", type=click.Choice(["table", "plain", "dict", "json"]), default="table")
+@publish_invocation
 def cmd_config_show(format):
     # TODO: parse values from potential docker-compose file?
 
     from localstack_ext import config as ext_config
 
-    from localstack import config
-
     assert config
     assert ext_config
 
@@ -254,29 +264,21 @@ def cmd_config_show(format):
 def print_config_json():
     import json
 
-    from localstack import config
-
     console.print(json.dumps(dict(config.collect_config_items())))
 
 
 def print_config_pairs():
-    from localstack import config
-
     for key, value in config.collect_config_items():
         console.print(f"{key}={value}")
 
 
 def print_config_dict():
-    from localstack import config
-
     console.print(dict(config.collect_config_items()))
 
 
 def print_config_table():
     from rich.table import Table
 
-    from localstack import config
-
     grid = Table(show_header=True)
     grid.add_column("Key")
     grid.add_column("Value")
@@ -288,8 +290,8 @@ def print_config_table():
 
 
 @localstack.command(name="ssh", help="Obtain a shell in the running LocalStack container")
+@publish_invocation
 def cmd_ssh():
-    from localstack import config
     from localstack.utils.docker_utils import DOCKER_CLIENT
     from localstack.utils.run import run
 
@@ -304,6 +306,100 @@ def cmd_ssh():
         pass
 
 
+@localstack.group(name="update", help="Update LocalStack components")
+def localstack_update():
+    pass
+
+
+@localstack_update.command(name="all", help="Update all LocalStack components")
+@click.pass_context
+@publish_invocation
+def cmd_update_all(ctx):
+    ctx.invoke(localstack_update.get_command(ctx, "localstack-cli"))
+    ctx.invoke(localstack_update.get_command(ctx, "docker-images"))
+
+
+@localstack_update.command(name="localstack-cli", help="Update LocalStack CLI tools")
+@publish_invocation
+def cmd_update_localstack_cli():
+    import subprocess
+    from subprocess import CalledProcessError
+
+    console.rule("Updating LocalStack CLI")
+    with console.status("Updating LocalStack CLI..."):
+        try:
+            subprocess.check_output(
+                [sys.executable, "-m", "pip", "install", "--upgrade", "localstack"]
+            )
+            console.print(":heavy_check_mark: LocalStack CLI updated")
+        except CalledProcessError:
+            console.print(":heavy_multiplication_x: LocalStack CLI update failed", style="bold red")
+
+
+@localstack_update.command(
+    name="docker-images", help="Update container images LocalStack depends on"
+)
+@publish_invocation
+def cmd_update_docker_images():
+    from localstack.utils.docker_utils import DOCKER_CLIENT
+
+    console.rule("Updating docker images")
+
+    all_images = DOCKER_CLIENT.get_docker_image_names(strip_latest=False)
+    image_prefixes = ["localstack/", "lambci/lambda:", "mlupin/docker-lambda:"]
+    localstack_images = [
+        image
+        for image in all_images
+        if any(
+            image.startswith(image_prefix) or image.startswith(f"docker.io/{image_prefix}")
+            for image_prefix in image_prefixes
+        )
+    ]
+    update_images(localstack_images)
+
+
+def update_images(image_list: List[str]):
+    from rich.markup import escape
+    from rich.progress import MofNCompleteColumn, Progress
+
+    from localstack.utils.container_utils.container_client import ContainerException
+    from localstack.utils.docker_utils import DOCKER_CLIENT
+
+    updated_count = 0
+    failed_count = 0
+    progress = Progress(
+        *Progress.get_default_columns(), MofNCompleteColumn(), transient=True, console=console
+    )
+    with progress:
+        for image in progress.track(image_list, description="Processing image..."):
+            try:
+                updated = False
+                hash_before_pull = DOCKER_CLIENT.inspect_image(image_name=image, pull=False)["Id"]
+                DOCKER_CLIENT.pull_image(image)
+                if (
+                    hash_before_pull
+                    != DOCKER_CLIENT.inspect_image(image_name=image, pull=False)["Id"]
+                ):
+                    updated = True
+                    updated_count += 1
+                console.print(
+                    f":heavy_check_mark: Image {escape(image)} {'updated' if updated else 'up-to-date'}.",
+                    style="bold" if updated else None,
+                    highlight=False,
+                )
+            except ContainerException as e:
+                console.print(
+                    f":heavy_multiplication_x: Image {escape(image)} pull failed: {e.message}",
+                    style="bold red",
+                    highlight=False,
+                )
+                failed_count += 1
+    console.rule()
+    console.print(
+        f"Images updated: {updated_count}, Images failed: {failed_count}, total images processed: {len(image_list)}."
+    )
+
+
 # legacy support
 @localstack.group(
     name="infra",
@@ -317,6 +413,7 @@ def infra():
 @click.pass_context
 @click.option("--docker", is_flag=True, help="Start LocalStack in a docker container (default)")
 @click.option("--host", is_flag=True, help="Start LocalStack directly on the host")
+@publish_invocation
 def cmd_infra_start(ctx, *args, **kwargs):
     ctx.invoke(cmd_start, *args, **kwargs)
 
@@ -332,14 +429,9 @@ class DockerStatus(TypedDict, total=False):
 
 
 def print_docker_status(format):
-    from localstack import config
     from localstack.utils import docker_utils
-    from localstack.utils.bootstrap import (
-        get_docker_image_details,
-        get_main_container_ip,
-        get_main_container_name,
-        get_server_version,
-    )
+    from localstack.utils.bootstrap import get_docker_image_details, get_server_version
+    from localstack.utils.container_networking import get_main_container_ip, get_main_container_name
 
     img = get_docker_image_details()
     cont_name = config.MAIN_CONTAINER_NAME
