@@ -41,15 +41,16 @@ BIND_HOST = "0.0.0.0"
 # AWS user account ID used for tests - TODO move to config.py
 if "TEST_AWS_ACCOUNT_ID" not in os.environ:
     os.environ["TEST_AWS_ACCOUNT_ID"] = "000000000000"
-TEST_AWS_ACCOUNT_ID = os.environ["TEST_AWS_ACCOUNT_ID"]
+
+# WARNING:
+# Do not use this constant to access the Account ID.
+# Use `localstack.aws.accounts.get_aws_account_id()` instead.
+_TEST_AWS_ACCOUNT_ID = os.environ["TEST_AWS_ACCOUNT_ID"]
 
 # root code folder
 MODULE_MAIN_PATH = os.path.dirname(os.path.realpath(__file__))
 # TODO rename to "ROOT_FOLDER"!
 LOCALSTACK_ROOT_FOLDER = os.path.realpath(os.path.join(MODULE_MAIN_PATH, ".."))
-INSTALL_DIR_INFRA = os.path.join(
-    MODULE_MAIN_PATH, "infra"
-)  # FIXME: deprecated, use config.dirs.infra
 
 # virtualenv folder
 LOCALSTACK_VENV_FOLDER = os.environ.get("VIRTUAL_ENV")
@@ -62,6 +63,9 @@ if not LOCALSTACK_VENV_FOLDER:
             os.path.join(LOCALSTACK_ROOT_FOLDER, "..", "..", "..")
         )
 
+# default volume directory containing shared data
+DEFAULT_VOLUME_DIR = "/var/lib/localstack"
+
 # API Gateway path to indicate a user request sent to the gateway
 PATH_USER_REQUEST = "_user_request_"
 
@@ -78,6 +82,9 @@ INTERNAL_RESOURCE_PATH = "/_localstack"
 # environment variable name to tag local test runs
 ENV_INTERNAL_TEST_RUN = "LOCALSTACK_INTERNAL_TEST_RUN"
 
+# environment variable name to tag collect metrics during a test run
+ENV_INTERNAL_TEST_COLLECT_METRIC = "LOCALSTACK_INTERNAL_TEST_COLLECT_METRIC"
+
 # environment variable that flags whether pro was activated. do not use for security purposes!
 ENV_PRO_ACTIVATED = "PRO_ACTIVATED"
 
@@ -99,9 +106,6 @@ FALSE_STRINGS = ("0", "false", "False")
 # strings with valid log levels for LS_LOG
 LOG_LEVELS = ("trace-internal", "trace", "debug", "info", "warn", "error", "warning")
 
-# Lambda defaults
-LAMBDA_TEST_ROLE = "arn:aws:iam::%s:role/lambda-test-role" % TEST_AWS_ACCOUNT_ID
-
 # the version of elasticsearch that is pre-seeded into the base image (sync with Dockerfile.base)
 ELASTICSEARCH_DEFAULT_VERSION = "Elasticsearch_7.10"
 # See https://docs.aws.amazon.com/ja_jp/elasticsearch-service/latest/developerguide/aes-supported-plugins.html
@@ -142,7 +146,7 @@ LIBSQLITE_AARCH64_URL = f"{MAVEN_REPO_URL}/io/github/ganadist/sqlite4java/libsql
 # API endpoint for analytics events
 API_ENDPOINT = os.environ.get("API_ENDPOINT") or "https://api.localstack.cloud/v1"
 # new analytics API endpoint
-ANALYTICS_API = os.environ.get("ANALYTICS_API") or "https://analytics.localstack.cloud/v0"
+ANALYTICS_API = os.environ.get("ANALYTICS_API") or "https://analytics.localstack.cloud/v1"
 
 # environment variable to indicates that this process is running the Web UI
 LOCALSTACK_WEB_PROCESS = "LOCALSTACK_WEB_PROCESS"
@@ -168,6 +172,11 @@ TEST_AWS_SECRET_ACCESS_KEY = "test"
 INTERNAL_AWS_ACCESS_KEY_ID = "__internal_call__"
 INTERNAL_AWS_SECRET_ACCESS_KEY = "__internal_call__"
 
+# This header must be set to the AWS Account ID
+# Presence of this header in an incoming request typically means that the request originated within localstack,
+# i.e. it is an internal cross-service call.
+HEADER_LOCALSTACK_ACCOUNT_ID = "x-localstack-account-id"
+
 # trace log levels (excluding/including internal API calls), configurable via $LS_LOG
 LS_LOG_TRACE = "trace"
 LS_LOG_TRACE_INTERNAL = "trace-internal"
@@ -195,23 +204,3 @@ OS_USER_OPENSEARCH = "localstack"
 
 # output string that indicates that the stack is ready
 READY_MARKER_OUTPUT = "Ready."
-
-# hardcoded AWS account ID used by moto
-MOTO_ACCOUNT_ID = TEST_AWS_ACCOUNT_ID
-
-
-def patch_moto_account_id():
-    # fix moto account ID - note: this needs to be executed before any other moto imports
-    try:
-        from moto import core as moto_core
-        from moto.core import models as moto_core_models
-
-        moto_core.ACCOUNT_ID = moto_core_models.ACCOUNT_ID = MOTO_ACCOUNT_ID
-    except Exception:
-        # ignore import errors
-        pass
-
-
-if not os.environ.get("SKIP_PATCH_MOTO_ACCOUNT_ID"):
-    # allow skipping this (importing moto takes a long time, and it's not necessary for the CLI)
-    patch_moto_account_id()
