@@ -32,19 +32,16 @@ LAMBDA_RUNTIME_PYTHON37 = "python3.7"
 LAMBDA_RUNTIME_PYTHON38 = "python3.8"
 LAMBDA_RUNTIME_PYTHON39 = "python3.9"
 LAMBDA_RUNTIME_NODEJS = "nodejs"
-LAMBDA_RUNTIME_NODEJS10X = "nodejs10.x"
 LAMBDA_RUNTIME_NODEJS12X = "nodejs12.x"
 LAMBDA_RUNTIME_NODEJS14X = "nodejs14.x"
+LAMBDA_RUNTIME_NODEJS16X = "nodejs16.x"
 LAMBDA_RUNTIME_JAVA8 = "java8"
 LAMBDA_RUNTIME_JAVA8_AL2 = "java8.al2"
 LAMBDA_RUNTIME_JAVA11 = "java11"
-LAMBDA_RUNTIME_DOTNETCORE2 = "dotnetcore2.0"
-LAMBDA_RUNTIME_DOTNETCORE21 = "dotnetcore2.1"
 LAMBDA_RUNTIME_DOTNETCORE31 = "dotnetcore3.1"
 LAMBDA_RUNTIME_DOTNET6 = "dotnet6"
 LAMBDA_RUNTIME_GOLANG = "go1.x"
 LAMBDA_RUNTIME_RUBY = "ruby"
-LAMBDA_RUNTIME_RUBY25 = "ruby2.5"
 LAMBDA_RUNTIME_RUBY27 = "ruby2.7"
 LAMBDA_RUNTIME_PROVIDED = "provided"
 LAMBDA_RUNTIME_PROVIDED_AL2 = "provided.al2"
@@ -56,8 +53,6 @@ LAMBDA_DEFAULT_STARTING_POSITION = "LATEST"
 
 # List of Dotnet Lambda runtime names
 DOTNET_LAMBDA_RUNTIMES = [
-    LAMBDA_RUNTIME_DOTNETCORE2,
-    LAMBDA_RUNTIME_DOTNETCORE21,
     LAMBDA_RUNTIME_DOTNETCORE31,
     LAMBDA_RUNTIME_DOTNET6,
 ]
