@@ -97,12 +97,14 @@ from localstack.services.dynamodb.utils import (
     extract_table_name_from_partiql_update,
 )
 from localstack.services.dynamodbstreams import dynamodbstreams_api
+from localstack.services.dynamodbstreams.dynamodbstreams_api import (
+    get_and_increment_sequence_number_counter,
+)
 from localstack.services.edge import ROUTER
 from localstack.services.generic_proxy import RegionBackend
 from localstack.services.plugins import ServiceLifecycleHook
 from localstack.utils.analytics import event_publisher
 from localstack.utils.aws import aws_stack
-from localstack.utils.bootstrap import is_api_enabled
 from localstack.utils.collections import select_attributes
 from localstack.utils.common import short_uid, to_bytes
 from localstack.utils.json import BytesEncoder
@@ -209,9 +211,7 @@ class EventForwarder:
             if not stream_type:
                 continue
             if "SequenceNumber" not in ddb_record:
-                ddb_record["SequenceNumber"] = str(
-                    dynamodbstreams_api.DynamoDBStreamsBackend.get_and_increment_sequence_number_counter()
-                )
+                ddb_record["SequenceNumber"] = str(get_and_increment_sequence_number_counter())
             # KEYS_ONLY  - Only the key attributes of the modified item are written to the stream
             if stream_type == "KEYS_ONLY":
                 ddb_record.pop("OldImage", None)
@@ -1212,9 +1212,6 @@ class DynamoDBProvider(DynamodbApi, ServiceLifecycleHook):
 
     def delete_all_event_source_mappings(self, table_arn):
         if table_arn:
-            # fix start dynamodb service without lambda
-            if not is_api_enabled("lambda"):
-                return
 
             lambda_client = aws_stack.connect_to_service("lambda")
             result = lambda_client.list_event_source_mappings(EventSourceArn=table_arn)
