@@ -15,24 +15,24 @@ DDB_KINESIS_STREAM_NAME_PREFIX = "__ddb_stream_"
 
 LOG = logging.getLogger(__name__)
 
+_SEQUENCE_MTX = threading.RLock()
+_SEQUENCE_NUMBER_COUNTER = 1
+
 
 class DynamoDBStreamsBackend(RegionBackend):
-    SEQUENCE_NUMBER_COUNTER = 1
-
-    _mutex = threading.RLock()
-
     # maps table names to DynamoDB stream descriptions
     ddb_streams: Dict[str, dict]
 
     def __init__(self):
         self.ddb_streams = {}
 
-    @classmethod
-    def get_and_increment_sequence_number_counter(cls) -> int:
-        with cls._mutex:
-            cnt = cls.SEQUENCE_NUMBER_COUNTER
-            cls.SEQUENCE_NUMBER_COUNTER += 1
-            return cnt
+
+def get_and_increment_sequence_number_counter() -> int:
+    global _SEQUENCE_NUMBER_COUNTER
+    with _SEQUENCE_MTX:
+        cnt = _SEQUENCE_NUMBER_COUNTER
+        _SEQUENCE_NUMBER_COUNTER += 1
+        return cnt
 
 
 def add_dynamodb_stream(
