@@ -4,13 +4,14 @@ import json
 import logging
 import re
 import traceback
-from typing import Dict, Optional
+from typing import Dict, List, Optional
 
 import botocore
 from moto.ec2.utils import generate_route_id
 
 from localstack import config
-from localstack.constants import FALSE_STRINGS, S3_STATIC_WEBSITE_HOSTNAME, TEST_AWS_ACCOUNT_ID
+from localstack.aws.accounts import get_aws_account_id
+from localstack.constants import FALSE_STRINGS, S3_STATIC_WEBSITE_HOSTNAME
 from localstack.services.cloudformation.deployment_utils import (
     PLACEHOLDER_AWS_NO_VALUE,
     PLACEHOLDER_RESOURCE_NAME,
@@ -123,6 +124,8 @@ def get_service_name(resource):
         return "cognito-idp"
     if parts[-2] == "Elasticsearch":
         return "es"
+    if parts[-2] == "OpenSearchService":
+        return "opensearch"
     if parts[-2] == "KinesisFirehose":
         return "firehose"
     if parts[-2] == "ResourceGroups":
@@ -423,7 +426,7 @@ def resolve_ref(stack, ref, attribute):
         # TODO return proper stack id!
         return stack_name
     if ref == "AWS::AccountId":
-        return TEST_AWS_ACCOUNT_ID
+        return get_aws_account_id()
     if ref == "AWS::NoValue":
         return PLACEHOLDER_AWS_NO_VALUE
     if ref == "AWS::NotificationARNs":
@@ -1064,10 +1067,6 @@ def determine_resource_physical_id(resource_id, stack=None, attribute=None):
         if attribute == "Arn":
             return aws_stack.s3_bucket_arn(resource_props.get("BucketName"))
         return resource_props.get("BucketName")  # Note: "Ref" returns bucket name in AWS
-    elif resource_type == "IAM::Role":
-        if attribute == "Arn":
-            return aws_stack.role_arn(resource_props.get("RoleName"))
-        return resource_props.get("RoleName")
     elif resource_type == "IAM::Policy":
         if attribute == "Arn":
             return aws_stack.policy_arn(resource_props.get("PolicyName"))
@@ -1214,7 +1213,7 @@ class TemplateDeployer:
 
     def apply_change_set(self, change_set):
         action = "CREATE"
-        change_set.stack.set_stack_status("%s_IN_PROGRESS" % action)
+        change_set.stack.set_stack_status(f"{action}_IN_PROGRESS")
         try:
             self.apply_changes(
                 change_set.stack,
@@ -1226,14 +1225,15 @@ class TemplateDeployer:
             LOG.info(
                 "Unable to apply change set %s: %s", change_set.metadata.get("ChangeSetName"), e
             )
-            change_set.metadata["Status"] = "%s_FAILED" % action
-            self.stack.set_stack_status("%s_FAILED" % action)
+            change_set.metadata["Status"] = f"{action}_FAILED"
+            self.stack.set_stack_status(f"{action}_FAILED")
             raise
 
     def update_stack(self, new_stack):
         self.stack.set_stack_status("UPDATE_IN_PROGRESS")
         # apply changes
         self.apply_changes(self.stack, new_stack, stack_name=self.stack.stack_name, action="UPDATE")
+        self.stack.set_time_attribute("LastUpdatedTime")
 
     def delete_stack(self):
         if not self.stack:
@@ -1251,6 +1251,7 @@ class TemplateDeployer:
                 self.stack.set_resource_status(resource_id, "DELETE_COMPLETE")
         # update status
         self.stack.set_stack_status("DELETE_COMPLETE")
+        self.stack.set_time_attribute("DeletionTime")
 
     # ----------------------------
     # DEPENDENCY RESOLUTION UTILS
@@ -1437,12 +1438,27 @@ class TemplateDeployer:
 
             parameters[logical_id] = param
 
-        parameters.update({p["ParameterKey"]: p for p in new_stack.metadata["Parameters"]})
+        def _update_params(params_list: List[Dict]):
+            for param in params_list:
+                # make sure we preserve parameter values if UsePreviousValue=true
+                if not param.get("UsePreviousValue"):
+                    parameters.update({param["ParameterKey"]: param})
 
+        _update_params(new_stack.metadata["Parameters"])
         for change_set in new_stack.change_sets:
-            parameters.update({p["ParameterKey"]: p for p in change_set.metadata["Parameters"]})
+            _update_params(change_set.metadata["Parameters"])
 
         # TODO: unclear/undocumented behavior in implicitly updating old_stack parameter here
+        # Note: Indeed it seems that parameters from Change Sets are applied to a stack
+        #   itself, and are preserved even after a change set has been deleted. However,
+        #   a proper implementation would distinguish between (1) Change Sets and (2) Change
+        #   Set Executions - the former are only a template for the changes to be applied,
+        #   whereas the latter actually perform changes (including parameter updates).
+        #   Also, (1) can be deleted, and (2) can only be rolled back (in case of errors).
+        #   Once we have the distinction between (1) and (2) in place, this logic (updating
+        #   the parameters of the stack itself) will become obsolete, then the parameter
+        #   values can be determined by replaying the values of the sequence of (immutable)
+        #   Change Set Executions.
         old_stack.metadata["Parameters"] = [v for v in parameters.values() if v]
 
     # TODO: fix circular import with cloudformation_api.py when importing Stack here
@@ -1453,6 +1469,7 @@ class TemplateDeployer:
         initialize=False,
         change_set_id=None,
         append_to_changeset=False,
+        filter_unchanged_resources=False,
     ):
         from localstack.services.cloudformation.provider import StackChangeSet
 
@@ -1466,8 +1483,13 @@ class TemplateDeployer:
         for action, items in (("Remove", deletes), ("Add", adds), ("Modify", modifies)):
             for item in items:
                 item["Properties"] = item.get("Properties", {})
-                change = self.get_change_config(action, item, change_set_id=change_set_id)
-                changes.append(change)
+                if (
+                    not filter_unchanged_resources
+                    or action != "Modify"
+                    or self.resource_config_differs(item)
+                ):
+                    change = self.get_change_config(action, item, change_set_id=change_set_id)
+                    changes.append(change)
 
         # append changes to change set
         if append_to_changeset and isinstance(new_stack, StackChangeSet):
@@ -1527,7 +1549,7 @@ class TemplateDeployer:
         def _run(*args):
             try:
                 self.do_apply_changes_in_loop(changes, stack, stack_name)
-                status = "%s_COMPLETE" % action
+                status = f"{action}_COMPLETE"
             except Exception as e:
                 LOG.debug(
                     'Error applying changes for CloudFormation stack "%s": %s %s',
@@ -1535,16 +1557,14 @@ class TemplateDeployer:
                     e,
                     traceback.format_exc(),
                 )
-                status = "%s_FAILED" % action
+                status = f"{action}_FAILED"
             stack.set_stack_status(status)
             if isinstance(new_stack, StackChangeSet):
                 new_stack.metadata["Status"] = status
-                new_stack.metadata["ExecutionStatus"] = (
-                    "EXECUTE_FAILED" if "FAILED" in status else "EXECUTE_COMPLETE"
-                )
-                new_stack.metadata["StatusReason"] = "Deployment %s" % (
-                    "failed" if "FAILED" in status else "succeeded"
-                )
+                exec_result = "EXECUTE_FAILED" if "FAILED" in status else "EXECUTE_COMPLETE"
+                new_stack.metadata["ExecutionStatus"] = exec_result
+                result = "failed" if "FAILED" in status else "succeeded"
+                new_stack.metadata["StatusReason"] = f"Deployment {result}"
 
         # run deployment in background loop, to avoid client network timeouts
         return start_worker_thread(_run)
@@ -1598,6 +1618,13 @@ class TemplateDeployer:
                         if not self.all_resource_dependencies_satisfied(resource):
                             j += 1
                             continue
+                    elif action == "Remove":
+                        should_remove = self.prepare_should_deploy_change(
+                            resource_id, change, stack, new_resources
+                        )
+                        if not should_remove:
+                            del changes[j]
+                            continue
                     self.apply_change(change, stack=stack)
                     changes_done.append(change)
                     del changes[j]
@@ -1651,6 +1678,13 @@ class TemplateDeployer:
                     resource.get("Type"),
                 )
                 return False
+        elif action == "Remove":
+            should_remove = self.is_deployable_resource(resource)
+            if not should_remove:
+                LOG.debug(
+                    f"Action 'remove' not yet implemented for CF resource type {resource.get('Type')}"
+                )
+            return should_remove
         return True
 
     def apply_change(self, change, stack):
