@@ -15,12 +15,9 @@ import boto3
 import requests
 
 from localstack import config
-from localstack.constants import (
-    LAMBDA_TEST_ROLE,
-    LOCALSTACK_ROOT_FOLDER,
-    LOCALSTACK_VENV_FOLDER,
-    TEST_AWS_ACCOUNT_ID,
-)
+from localstack.aws.accounts import get_aws_account_id
+from localstack.constants import LOCALSTACK_ROOT_FOLDER, LOCALSTACK_VENV_FOLDER
+from localstack.services.awslambda.lambda_api import LAMBDA_TEST_ROLE
 from localstack.services.awslambda.lambda_utils import (
     LAMBDA_DEFAULT_HANDLER,
     LAMBDA_DEFAULT_RUNTIME,
@@ -273,7 +270,7 @@ def create_lambda_function(
         "FunctionName": func_name,
         "Runtime": runtime,
         "Handler": handler,
-        "Role": role or LAMBDA_TEST_ROLE,
+        "Role": role or LAMBDA_TEST_ROLE.format(account_id=get_aws_account_id()),
         "Code": lambda_code,
         "Timeout": timeout or LAMBDA_TIMEOUT_SEC,
         "Environment": dict(Variables=envvars),
@@ -309,6 +306,7 @@ def connect_api_gateway_to_http_with_lambda_proxy(
     auth_type=None,
     auth_creator_func=None,
     http_method=None,
+    client=None,
 ):
     if methods is None:
         methods = []
@@ -336,6 +334,7 @@ def connect_api_gateway_to_http_with_lambda_proxy(
         resources=resources,
         stage_name=stage_name,
         auth_creator_func=auth_creator_func,
+        client=client,
     )
 
 
@@ -511,7 +510,7 @@ def get_sample_arn(service, resource):
     return "arn:aws:%s:%s:%s:%s" % (
         service,
         aws_stack.get_region(),
-        TEST_AWS_ACCOUNT_ID,
+        get_aws_account_id(),
         resource,
     )
 
@@ -569,8 +568,12 @@ def get_lambda_log_group_name(function_name):
     return "/aws/lambda/{}".format(function_name)
 
 
-def check_expected_lambda_log_events_length(expected_length, function_name, regex_filter=None):
-    events = get_lambda_log_events(function_name, regex_filter=regex_filter)
+def check_expected_lambda_log_events_length(
+    expected_length, function_name, regex_filter=None, logs_client=None
+):
+    events = get_lambda_log_events(
+        function_name, regex_filter=regex_filter, logs_client=logs_client
+    )
     events = [line for line in events if line not in ["\x1b[0m", "\\x1b[0m"]]
     if len(events) != expected_length:
         print(
@@ -661,7 +664,7 @@ def http_server(handler, host="127.0.0.1", port=None) -> str:
 
     host = host
     port = port or get_free_tcp_port()
-    thread = run_server(port, host, handler=handler, asynchronous=True)
+    thread = run_server(port, [host], handler=handler, asynchronous=True)
     url = f"http://{host}:{port}"
     assert poll_condition(
         lambda: is_port_open(port), timeout=5
